netapp_ontap.models.lun_movement API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.lun_movement`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LunMovementSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LunMovement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `max_throughput GET POST PATCH`

    The maximum data throughput that should be utilized in support of the LUN movement. This property can be used to throttle a transfer and limit its impact on the performance of the source and destination nodes. The specified value will be rounded up to the nearest megabyte.
    If this property is not specified in a POST that begins a LUN movement, throttling is not applied to the data transfer.
    For more information, see Size properties in the docs section of the ONTAP REST API documentation.
    This property is valid only in a POST that begins a LUN movement or a PATCH when a LUN movement is already in process.

  `paths GET POST PATCH`

    The paths field of the lun_movement.

  `progress GET PATCH`

    The progress field of the lun_movement.